@@ -64,6 +64,7 @@ class Trainer(Fit):
         max_train_timeout: datetime.timedelta | None = None,
         cutoff_dt: datetime.datetime | None = None,
         embedding_cols: list[list[str]] | None = None,
+        allowed_models: set[str] | None = None,
     ):
         tqdm.tqdm.pandas()
 
@@ -154,7 +155,8 @@ class Trainer(Fit):
         self._dt_column = dt_column
         self._max_train_timeout = max_train_timeout
         self._cutoff_dt = cutoff_dt
-        self._embedding_cols = embedding_cols
+        self.embedding_cols = embedding_cols
+        self._allowed_models = allowed_models
 
     def _provide_study(self, column: str) -> optuna.Study:
         storage_name = f"sqlite:///{self._folder}/{column}/{_STUDYDB_FILENAME}"
@@ -249,7 +251,7 @@ class Trainer(Fit):
 
                     # Perform common reductions
                     start_reducer = time.time()
-                    reducer = CombinedReducer(self._embedding_cols)
+                    reducer = CombinedReducer(self.embedding_cols)
                     reducer.set_options(trial, x)
                     x_train = reducer.fit_transform(x_train, y=y_train)
                     x_test = reducer.transform(x_test)
@@ -265,7 +267,7 @@ class Trainer(Fit):
                     print(f"Row weights took {time.time() - start_row_weights}")
 
                     # Create model
-                    model = ModelRouter()
+                    model = ModelRouter(self._allowed_models)
                     model.set_options(trial, x)
 
                     # Train
@@ -381,7 +383,7 @@ class Trainer(Fit):
                 )
             while (
                 study.best_trial.value is None or study.best_trial.value == _BAD_OUTPUT
-            ):
+            ) and len(study.trials) < 1000:
                 logging.info("Performing extra train")
                 study.optimize(
                     test_objective,
@@ -514,10 +516,10 @@ class Trainer(Fit):
                 date_str = dates[-1].isoformat()
                 folder = os.path.join(column_path, date_str)
 
-                reducer = CombinedReducer(self._embedding_cols)
+                reducer = CombinedReducer(self.embedding_cols)
                 reducer.load(folder)
 
-                model = ModelRouter()
+                model = ModelRouter(None)
                 model.load(folder)
 
                 selector = Selector(model)
@@ -570,7 +572,7 @@ class Trainer(Fit):
                 if not os.path.isdir(date_path):
                     continue
                 try:
-                    model = ModelRouter()
+                    model = ModelRouter(None)
                     model.load(date_path)
                     feature_importances[date_str] = model.feature_importances
                 except FileNotFoundError as exc:
